import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { ButtonType, ButtonState, ButtonVariant } from './types';
export declare type ButtonRef = React.Ref<HTMLButtonElement>;
export declare type ButtonProps = React.PropsWithChildren<PropsWithMetadata<{
    /** Makes the component behave as a block element (take up the whole available space) */
    block?: boolean;
    /** Allows providing a custom class name */
    className?: string;
    /** Determines the state of the button */
    buttonState?: ButtonState;
    /** A callback that will be fired ones the button is clicked */
    onClick?: React.MouseEventHandler;
    /** Allows providing the custom CSS */
    style?: React.CSSProperties;
    /** Tab index HTML property */
    tabIndex?: number;
    /**
     * @deprecated This prop has been replaced by variant and will be removed in an upcoming release.
     */
    theme?: ButtonVariant;
    /** Allows specifying the variant of the button */
    variant?: ButtonVariant;
    /** Button Type HTML property */
    type?: ButtonType;
}>> & Omit<React.ComponentPropsWithoutRef<'button'>, 'disabled'>;
declare const Button: React.ForwardRefExoticComponent<{
    /** Makes the component behave as a block element (take up the whole available space) */
    block?: boolean | undefined;
    /** Allows providing a custom class name */
    className?: string | undefined;
    /** Determines the state of the button */
    buttonState?: ButtonState | undefined;
    /** A callback that will be fired ones the button is clicked */
    onClick?: React.MouseEventHandler<Element> | undefined;
    /** Allows providing the custom CSS */
    style?: React.CSSProperties | undefined;
    /** Tab index HTML property */
    tabIndex?: number | undefined;
    /**
     * @deprecated This prop has been replaced by variant and will be removed in an upcoming release.
     */
    theme?: ButtonVariant | undefined;
    /** Allows specifying the variant of the button */
    variant?: ButtonVariant | undefined;
    /** Button Type HTML property */
    type?: ButtonType | undefined;
} & {
    metadata?: import("@highlight-ui/utils-commons").ComponentMetadata | undefined; /** A callback that will be fired ones the button is clicked */
} & {
    children?: React.ReactNode;
} & Omit<Pick<React.DetailedHTMLProps<React.ButtonHTMLAttributes<HTMLButtonElement>, HTMLButtonElement>, "key" | keyof React.ButtonHTMLAttributes<HTMLButtonElement>>, "disabled"> & React.RefAttributes<HTMLButtonElement>>;
export default Button;
