import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { ButtonType, ButtonState, ButtonVariant } from './types';
export declare type IconButtonRef = React.Ref<HTMLButtonElement>;
export declare type IconButtonProps = React.PropsWithChildren<PropsWithMetadata<{
    /** Allows providing a custom class name */
    className?: string;
    /** Determines the state of the button */
    buttonState?: ButtonState;
    /** Provides the icon by icon's name */
    icon: string;
    /** Sets the reference to the aria-label attribute */
    ariaLabel: string;
    /** A callback that will be fired ones the button is clicked */
    onClick?: React.MouseEventHandler;
    /** Allows providing the custom CSS */
    style?: React.CSSProperties;
    /** Tab index HTML property */
    tabIndex?: number;
    /**
     * @deprecated This prop has been replaced by variant and will be removed in an upcoming release.
     */
    theme?: ButtonVariant;
    /** Allows specifying the styling of the button */
    variant?: ButtonVariant;
    /** Button Type HTML property */
    type?: ButtonType;
}>> & Omit<React.ComponentPropsWithoutRef<'button'>, 'disabled'>;
declare const IconButton: React.ForwardRefExoticComponent<{
    /** Allows providing a custom class name */
    className?: string | undefined;
    /** Determines the state of the button */
    buttonState?: ButtonState | undefined;
    /** Provides the icon by icon's name */
    icon: string;
    /** Sets the reference to the aria-label attribute */
    ariaLabel: string;
    /** A callback that will be fired ones the button is clicked */
    onClick?: React.MouseEventHandler<Element> | undefined;
    /** Allows providing the custom CSS */
    style?: React.CSSProperties | undefined;
    /** Tab index HTML property */
    tabIndex?: number | undefined;
    /**
     * @deprecated This prop has been replaced by variant and will be removed in an upcoming release.
     */
    theme?: ButtonVariant | undefined;
    /** Allows specifying the styling of the button */
    variant?: ButtonVariant | undefined;
    /** Button Type HTML property */
    type?: ButtonType | undefined;
} & {
    metadata?: import("@highlight-ui/utils-commons").ComponentMetadata | undefined;
} & {
    children?: React.ReactNode;
} & Omit<Pick<React.DetailedHTMLProps<React.ButtonHTMLAttributes<HTMLButtonElement>, HTMLButtonElement>, "key" | keyof React.ButtonHTMLAttributes<HTMLButtonElement>>, "disabled"> & React.RefAttributes<HTMLButtonElement>>;
export default IconButton;
